Llevar a cabo una evaluación de riesgos con OiRA | OiRA

Temas

# Llevar a cabo una evaluación de riesgos con OiRA

## Iniciar una nueva sesión

Para iniciar una nueva evaluación de riesgos, haga clic en el enlace «Iniciar una nueva sesión».

## Apertura de una evaluación de riesgos

Una vez que haya iniciado una evaluación de riesgos, podrá recuperarla en cualquier momento mediante el tablero de control «Mis evaluaciones de riesgos». Desde este mismo lugar, puede iniciar una nueva evaluación.

Tablero de control

## Navegar por una evaluación de riesgos

Cada evaluación de riesgos consta de varios pasos. Se pueden ver en el menú principal, en el lado izquierdo:

- Preparación
- Participación
- Identificación + Evaluación
- Plan de acción
- Informe
- Grado de cumplimentación

En función de las decisiones adoptadas por los socios o los desarrolladores de las herramientas OiRA, la arquitectura de la herramienta específica puede variar. En algunas, la fase de identificación y evaluación de riesgos también incluye directamente el plan de acción. En este caso, el menú de la izquierda contiene los siguientes puntos:

- Preparación
- Participación
- Evaluación
- Informe
- Grado de cumplimentación

## Preparación

La preparación es donde usted inicia automáticamente cada sesión o herramienta. En esta página se asigna un nombre a la evaluación de riesgos con el fin de ayudarle posteriormente a distinguir las distintas evaluaciones de riesgos que haya obtenido con la herramienta.

El enlace «Aprenda más sobre esta herramienta…» muestra información adicional, específicamente sobre la herramienta seleccionada y las partes que intervienen en el desarrollo.

Después de clicar el botón «Iniciar», es posible que se le formulen algunas preguntas adicionales, dependiendo de la herramienta que esté utilizando. Esta página de preparación con «preguntas de perfil» solo aparece en las herramientas que ofrecen esta opción.

Aquí puede:

- Seleccionar u omitir situaciones en función de si resultan aplicables a la actividad de su empresa. Elija «Sí», si procede.
- Indique las múltiples unidades de negocio, sucursales o tiendas, etc. Los riesgos relacionados se repetirán para cada nombre que haya introducido.

La pantalla «Perfil» en el paso de Preparación

El paso de preparación es muy importante, ya que define con precisión el tipo de actividad y los riesgos relacionados a los que debe hacer frente su empresa. Después de clicar «Guardar y continuar», accederá automáticamente a la siguiente sección, «Participación».

Nota: Muchas herramientas no incluyen preguntas de perfil, ya que no utilizan esta función para dirigir la herramienta. En este caso, esta pantalla salta automáticamente.

## Participación

Este paso le recuerda que es importante que los trabajadores participen y ofrece diferentes posibilidades para garantizarlo. En esta pantalla puede descargar o imprimir el contenido de la evaluación de riesgos para compartirlo con sus trabajadores. De esta manera, se asegura que estos puedan contribuir a la evaluación de la situación en su puesto de trabajo.

## Identificación + Evaluación

En esta fase, deberá identificar los peligros y los problemas de su empresa.

Nota: Según cómo el socio desarrollador de la herramienta OiRA haya configurado la herramienta, el paso «Plan de acción» (véase más adelante) ya puede integrarse en esta pantalla. En este caso, todo el paso se denomina «Evaluación» y los elementos que se describen a continuación en el apartado «Plan de acción» aparecerán con la identificación y la evaluación de cada riesgo.

Identificación + Evaluación.

A la izquierda de esta página, debajo de «Identificación + Evaluación» o «Evaluación», puede ver todos los temas o módulos que se incluyen en la herramienta. El tema que está viendo en este momento aparece resaltado.

Para cada riesgo individual, debe decidir si la declaración descrita de un estado positivo es válida para su empresa:

- Sí: si responde afirmativamente en el encabezado con un sí, no es necesario que haga nada más, ya que ha evaluado que el riesgo no existe.
- No: si responde con un no, debe tomar más medidas. En este caso, se le pedirá que decida medidas específicas.
- No procede: algunas declaraciones de riesgo le ofrecen la posibilidad de seleccionar «No procede» en caso de que el riesgo no sea pertinente para su empresa o centro de trabajo.

Normalmente, bajo cada declaración a la que debe responder, se incluye información adicional sobre el riesgo específico:

- Información: una breve descripción, opcionalmente con imágenes ilustrativas, con el fin de ofrecer más detalles sobre el riesgo.
- Recursos: información adicional sobre el riesgo, como referencias legales y políticas. En ocasiones, en este apartado también puede encontrar documentos adjuntos que le ayudarán a ampliar la información.
- Comentarios: aquí puede incluir sus comentarios, que aparecerán en su informe al final de la evaluación.

Después de responder a una declaración de riesgos, al continuar, el menú de la izquierda se actualizará con un símbolo en color, que indicará lo siguiente:

- Ha respondido afirmativamente (marca en verde).
- Ha respondido negativamente (cruz roja).
- Ha pospuesto (signo de interrogación en amarillo).
- En el caso de las preguntas sin respuesta, se mantiene el símbolo gris.

### Evaluación

En este paso, deberá evaluar la prioridad de un riesgo que haya identificado.

Evaluar un riesgo

Nota: En alguna herramienta OiRA puede ser que no se muestre la evaluación. Esto depende de cómo el socio la haya configurado.

Si ha identificado un riesgo como existente (cuando se muestra la cruz roja), aparecerá la sección de evaluación. En función del método de evaluación establecido para cada riesgo, deberá:

- Estimar directamente la prioridad: alta, media o baja.

Establecer la prioridad de un riesgo

o bien

- Responder a tres preguntas sobre la frecuencia, la gravedad y la probabilidad del riesgo, de manera que la prioridad pueda calcularse de acuerdo con sus respuestas.

Establecer variables para un riesgo

### Riesgos prioritarios

Algunos riesgos son considerados de alta importancia por el socio o el desarrollador que creó la herramienta específica. No es necesario calcular estos «riesgos prioritarios», ya que su prioridad se establecerá automáticamente como «alta».

Riesgos prioritarios

### Riesgos personalizados

Una vez haya terminado de responder a todos los temas de riesgo en «Identificación + Evaluación» o «Evaluación», accederá al tema opcional «Riesgos añadidos». En este caso, el botón «Añadir otro riesgo» le permitirá crear sus propias entradas.

En caso de que observe que determinados riesgos detectados en su puesto de trabajo o en su empresa no aparezcan en la herramienta, deberá añadir aquí los riesgos personalizados; podrá definir o formular íntegramente estos riesgos.

Riesgos personalizados

Un «riesgo personalizado» funciona de manera muy similar a los riesgos que ofrece OiRA, pero, evidentemente, es necesario que redacte su propio texto: una breve declaración en la que describa la situación problemática (declaración positiva) y, opcionalmente, una descripción más larga y detallada. También puede insertar una imagen para ilustrar una situación determinada.

Del mismo modo que ocurre con los riesgos previstos, debe declarar si el riesgo existe o no. Por lo tanto, tendrá la posibilidad de descartar los riesgos personalizados una vez que los haya abordado con éxito, aunque siempre los podrá conservar en su evaluación de riesgos a efectos de documentación.

Puede añadir tantos riesgos personalizados como sea necesario.

Añadir un riesgo personalizado

## Plan de acción

En este paso, usted decide las medidas que quiere aplicar para eliminar o mitigar los riesgos que ha identificado anteriormente.

Nota: Como se ha mencionado antes, el plan de acción se presenta como un paso separado resaltado en el menú de la izquierda o como un paso en cada riesgo identificado. En este último caso, el paso en el menú de la izquierda se identifica con el nombre de «Evaluación» e incluye tanto las declaraciones de riesgo que deben responderse como las soluciones que es preciso elegir.

La versión que se facilita depende de las decisiones que tome el socio o el desarrollador nacional de OiRA.

### Plan de acción integrado

Plan de acción integrado.

Si responde a una pregunta con un no, se desplegará el módulo del plan de acción, con el título «Medidas».

Puede seleccionar o definir sus medidas a partir de la lista de medidas propuestas.

### Plan de acción separado

Cuando el plan de acción es un paso separado, se podrá acceder a él a través del panel de navegación izquierdo

Clique el botón «Crear plan de acción» para empezar su plan.

En el paso del plan de acción, el menú principal de la izquierda solo muestra los riesgos marcados para acciones posteriores, dado que los otros riesgos se marcaron como no existentes.

Para cada riesgo al que haya respondido con un no durante el proceso de evaluación y para los riesgos prioritarios (independientemente de que se hayan respondido positiva o negativamente), deberá definir medidas.

Plan de acción

Puede seleccionar entre una lista de medidas propuestas por el sistema o definir sus propias medidas.

#### Añadir su propia medida

Añadir su propia medida

Pulse el botón «Añadir otra medida» para empezar a definir una medida preventiva. Complete la siguiente información:

- Describa el enfoque general que se adoptará para eliminar o reducir el riesgo.
- Indique opcionalmente el nivel de experiencia o los requisitos necesarios (por ejemplo, puede añadir si se necesita formación específica o experiencia externa para abordar este riesgo).
- Introduzca información sobre quién es la persona responsable de la aplicación.
- Defina un presupuesto, si procede.
- De manera opcional, establezca fechas para empezar a aplicar la medida y cuándo tiene previsto que finalice.

Puede añadir tantas medidas como sea necesario.

#### Añadir una medida preestablecida

En función de cómo haya configurado la herramienta el socio o el desarrollador correspondiente, se dispondrán de medidas preestablecidas para los riesgos individuales. Para elegir una o más medidas preestablecidas, haga clic en «Seleccionar medidas preestablecidas».

Se abre un menú emergente que muestra todas las medidas propuestas. Clique en el botón «Añadir» que aparece detrás de las medidas que desea utilizar.

Las medidas preestablecidas se incluyen a continuación en su plan de acción. La descripción de lo que se debe hacer es fija, pero deberá cumplimentar los demás campos (responsabilidad, presupuesto y fechas).

Añadir una medida preestablecida.

Las medidas preestablecidas y las medidas que ha definido se pueden eliminar en cualquier momento.

## Informe

Después de finalizar el plan de acción, puede descargar un informe.

Si desea dejar un comentario para que se incluya en el informe, escriba su texto en este campo y guárdelo.

Comentar el informe

Consulte aquí para acceder a la información adicional sobre los diferentes informes y para saber cómo utilizarlos.

## Grado de cumplimentación

El pequeño gráfico circular que aparece en el menú de la izquierda muestra el progreso general que ha hecho en la herramienta.

La sección de grado de cumplimentación ofrece una visión general de cuántos riesgos ha identificado, cuántos de ellos ha abordado mediante la decisión de medidas y a cuántos riesgos o declaraciones no ha respondido todavía.

Página de grado de cumplimentación

Al acceder a la página de grado de cumplimentación, podrá ver cuánto ha avanzado en cada módulo. Esta información le puede ayudar a saber dónde es necesario seguir evaluando los riesgos o proporcionando medidas para los riesgos que ha identificado.

Scroll to top Load toolbar…
Back

## 3-carrying-out-a-risk-assessment.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More